@@ -191,7 +191,7 @@ mod tests {
             toc.append_entry(toc_edition);
         }
 
-        let pretty_config = ron::ser::PrettyConfig::new().with_new_line("".to_string());
+        let pretty_config = ron::ser::PrettyConfig::new().new_line("".to_string());
 
         let res = ron::ser::to_string_pretty(&toc, pretty_config);
         assert_eq!(
